ParamMean: Parameter Average

Description Usage Arguments Value Examples

View source: R/WoLF_functionsV2.R

Description

Calculates the mean of the given biometric parameter along the mesaured chamber series per specimen. Intended to be used for the parameters backbend angle, septal angle and perimeter ratio.

Usage

1
ParamMean(param)

Arguments

param

name of the parameter to be processed

Value

the function returns the mean parameter for each specimens as a new column in the summary table

Examples

1

weder90/WoLF_R documentation built on Jan. 21, 2020, 12:18 a.m.