Description Usage Arguments Value Examples
View source: R/WoLF_functionsV2.R
Calculates the mean of the given biometric parameter along the mesaured chamber series per specimen. Intended to be used for the parameters backbend angle, septal angle and perimeter ratio.
1 | ParamMean(param)
|
param |
name of the parameter to be processed |
the function returns the mean parameter for each specimens as a new column in the summary table
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.